.. SPDX-FileCopyrightText: 2025 icalendar-anonymizer contributors
.. SPDX-License-Identifier: AGPL-3.0-or-later

=============
Configuration
=============

.. automodule:: icalendar_anonymizer._config
   :members:
   :undoc-members:
   :show-inheritance:
